create_new

Function create_new 

pub fn create_new(path: &Path) -> Result<File>
Create a new file without replacing an existing entry.

Errors

Returns a contextual error when the file exists or cannot be created.